@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ class ErrorDialog : public QDialog, public Ui::ErrorDialog
 	Q_OBJECT
 
 public:
-	ErrorDialog( QWidget* parent = 0, Qt::WindowFlags f = 0 );
+	ErrorDialog( QWidget* parent = 0, Qt::WindowFlags f = QFlag(0) );
 	~ErrorDialog();
 
 public slots:
